@@ -1,4 +1,4 @@
-# Copyright 2003-2009, Blue Dynamics Alliance - http://bluedynamics.com
+# Copyright 2009, Blue Dynamics Alliance - http://bluedynamics.com
 # GNU General Public Licence Version 2 or later
 
 from zope.interface import Attribute
@@ -9,4 +9,8 @@ class INode(ILocation, IFullMapping):
     """A node.
     """
     
-    path = Attribute(u"Path of target element as list")
\ No newline at end of file
+    path = Attribute(u"Path of target element as list")
+    
+    def filtereditems(interface):
+        """Return self.items() filtered by interface.
+        """
\ No newline at end of file
