@@ -1,4 +1,4 @@
-# Copyright 2003-2009, BlueDynamics Alliance - http://bluedynamics.com
+# Copyright 2009, BlueDynamics Alliance - http://bluedynamics.com
 # GNU General Public License Version 2 or later
 
 from zodict import zodict
@@ -29,6 +29,11 @@ class Node(zodict):
         path.reverse()
         return path
     
+    def filtereditems(self, interface):
+        for node in self.values():
+            if interface.providedBy(node):
+                yield node
+    
     def __repr__(self):
         return '<Node object \'%s\' at %s>' % (self.__name__,
                                                hex(id(self))[:-1])
